==> colemen_utils-2.10.66.tar.gz: colemen_utils-2.10.66/colemen_utilities/database_utils/MySQL/__init__.py <==
# pylint: disable=missing-function-docstring
# pylint: disable=missing-class-docstring
# pylint: disable=line-too-long
# pylint: disable=unused-import

from typing import TYPE_CHECKING
from typing import TypeVar as _TypeVar


# import colemen_utilities.database_utils.MySQL.MySQLDatabase as mysqlDB
# import colemen_utilities.database_utils.MySQL.Column as Column
# import colemen_utilities.database_utils.MySQL.CacheFile as cacheFile
from colemen_utilities.database_utils.MySQL.Column import *
from colemen_utilities.database_utils.MySQL.CacheFile import *
from colemen_utilities.database_utils.MySQL.SelectQuery import *
from colemen_utilities.database_utils.MySQL.UpdateQuery import *
from colemen_utilities.database_utils.MySQL.DeleteQuery import *
from colemen_utilities.database_utils.MySQL.Table import *

from colemen_utilities.database_utils.MySQL.MySQLDatabase import MySQLDatabase as MySQL
from colemen_utilities.database_utils.MySQL.MySQLDatabase import new


if TYPE_CHECKING:
    import colemen_utilities.database_utils.MySQL.MySQLDatabase as _mysqldb
    _db_mysql_database_type = _TypeVar('_db_mysql_database_type', bound=_mysqldb.MySQLDatabase)
    import colemen_utilities.database_utils.MySQL.Column.Column as _col
    _db_column_type = _TypeVar('_db_column_type', bound=_col.Column)
    import colemen_utilities.database_utils.MySQL.Column.Column as _col
    _db_column_sql_data_type = _TypeVar('_db_column_sql_data_type', bound=_col.Column.sql_data)
    import colemen_utilities.database_utils.MySQL.Column.Column as _col
    _db_column_validation_data_type = _TypeVar('_db_column_validation_data_type', bound=_col.Column.validation_data)
    import colemen_utilities.database_utils.MySQL.Column.Column as _col
    _db_column_form_data_type = _TypeVar('_db_column_form_data_type', bound=_col.Column.form_data)

    import colemen_utilities.database_utils.MySQL.Table.Table as _table
    _db_table_type = _TypeVar('_db_table_type', bound=_table.Table)


    import colemen_utilities.database_utils.MySQL.DeleteQuery as _deleteQuery
    _db_mysql_delete_query_type = _TypeVar('_db_mysql_delete_query_type', bound=_deleteQuery.DeleteQuery)

    import colemen_utilities.database_utils.MySQL.UpdateQuery as _updateQuery
    _db_mysql_update_query_type = _TypeVar('_db_mysql_update_query_type', bound=_updateQuery.UpdateQuery)

    import colemen_utilities.database_utils.MySQL.SelectQuery as _selectQuery
    _db_mysql_select_query_type = _TypeVar('_db_mysql_select_query_type', bound=_selectQuery.SelectQuery)

    import colemen_utilities.database_utils.MySQL.InsertQuery as _insertQuery
    _db_mysql_insert_query_type = _TypeVar('_db_mysql_insert_query_type', bound=_insertQuery.InsertQuery)

==> colemen_utils-2.10.67.tar.gz: colemen_utils-2.10.67/colemen_utilities/database_utils/MySQL/__init__.py <==
# pylint: disable=missing-function-docstring
# pylint: disable=missing-class-docstring
# pylint: disable=line-too-long
# pylint: disable=unused-import

from typing import TYPE_CHECKING
from typing import TypeVar as _TypeVar


# import colemen_utilities.database_utils.MySQL.MySQLDatabase as mysqlDB
# import colemen_utilities.database_utils.MySQL.Column as Column
# import colemen_utilities.database_utils.MySQL.CacheFile as cacheFile
from colemen_utilities.database_utils.MySQL.Column import *
from colemen_utilities.database_utils.MySQL.CacheFile import *
from colemen_utilities.database_utils.MySQL.SelectQuery import *
from colemen_utilities.database_utils.MySQL.UpdateQuery import *
from colemen_utilities.database_utils.MySQL.DeleteQuery import *
from colemen_utilities.database_utils.MySQL.Table import *

from colemen_utilities.database_utils.MySQL.MySQLDatabase import MySQLDatabase as MySQL
from colemen_utilities.database_utils.MySQL.MySQLDatabase import new

_db_mysql_database_type = None
_db_column_type = None
_db_column_sql_data_type = None
_db_column_validation_data_type = None
_db_column_form_data_type = None
_db_mysql_insert_query_type = None
_db_mysql_select_query_type = None
_db_mysql_update_query_type = None
_db_mysql_delete_query_type = None
_db_table_type = None

if TYPE_CHECKING:
    import colemen_utilities.database_utils.MySQL.MySQLDatabase as _mysqldb
    _db_mysql_database_type = _TypeVar('_db_mysql_database_type', bound=_mysqldb.MySQLDatabase)
    import colemen_utilities.database_utils.MySQL.Column.Column as _col
    _db_column_type = _TypeVar('_db_column_type', bound=_col.Column)
    import colemen_utilities.database_utils.MySQL.Column.Column as _col
    _db_column_sql_data_type = _TypeVar('_db_column_sql_data_type', bound=_col.Column.sql_data)
    import colemen_utilities.database_utils.MySQL.Column.Column as _col
    _db_column_validation_data_type = _TypeVar('_db_column_validation_data_type', bound=_col.Column.validation_data)
    import colemen_utilities.database_utils.MySQL.Column.Column as _col
    _db_column_form_data_type = _TypeVar('_db_column_form_data_type', bound=_col.Column.form_data)

    import colemen_utilities.database_utils.MySQL.Table.Table as _table
    _db_table_type = _TypeVar('_db_table_type', bound=_table.Table)


    import colemen_utilities.database_utils.MySQL.DeleteQuery as _deleteQuery
    _db_mysql_delete_query_type = _TypeVar('_db_mysql_delete_query_type', bound=_deleteQuery.DeleteQuery)

    import colemen_utilities.database_utils.MySQL.UpdateQuery as _updateQuery
    _db_mysql_update_query_type = _TypeVar('_db_mysql_update_query_type', bound=_updateQuery.UpdateQuery)

    import colemen_utilities.database_utils.MySQL.SelectQuery as _selectQuery
    _db_mysql_select_query_type = _TypeVar('_db_mysql_select_query_type', bound=_selectQuery.SelectQuery)

    import colemen_utilities.database_utils.MySQL.InsertQuery as _insertQuery
    _db_mysql_insert_query_type = _TypeVar('_db_mysql_insert_query_type', bound=_insertQuery.InsertQuery)
